class PopupWindow:
    def __init__(self, title="Popup", message="Hello"):
        self.title = title
        self.message = message

    def show(self):
        self.draw()

    def draw(self):
        print("=" * 30)
        print(f"{self.title}")
        print("-" * 30)
        print(self.message)
        print("=" * 30)


class PopupApp:
    def __init__(self):
        self.windows = []

    def add_window(self, window):
        self.windows.append(window)

    def run(self):
        for window in self.windows:
            window.show()